@@ -8,7 +8,8 @@ import argparse
 import gnssrefl.gps as g
 import sys
 import subprocess
-
+import os
+import wget
 
 def main():
     """
@@ -25,7 +26,7 @@ def main():
 #   make sure environment variables exist.  set to current directory if not
     g.check_environ_variables()
 
-    orbit_list = ['igs', 'igr','jax','grg','wum','gbm','nav','gps','gps+glo','gnss','gfr']
+    orbit_list = ['igs', 'igr','jax','grg','wum','gbm','nav','gps','gps+glo','gnss','gfr','esa','gnss2']
 
 
 #   assign to normal variables
@@ -42,6 +43,7 @@ def main():
         # then you are using day of year as input
         doy = month
         year,month,day=g.ydoy2ymd(year, doy) 
+        doy,cdoy,cyyyy,cyy = g.ymd2doy(year,month,day)
     else:
         doy,cdoy,cyyyy,cyy = g.ymd2doy(year,month,day)
 
@@ -61,6 +63,8 @@ def main():
     if pCtr == 'gps+glo':
         pCtr = 'jax'
 
+    if pCtr == 'gfr':
+        pCtr = 'gbm' # since I cannot get their direct address to work 
 
     if pCtr == 'nav':
         navname,navdir,foundit = g.getnavfile(year, month, day) 
@@ -70,8 +74,17 @@ def main():
         if (pCtr == 'igs') or (pCtr == 'igr'):
             filename, fdir, foundit = g.getsp3file_flex(year,month,day,pCtr)
         else:
-            if pCtr == 'gfr':
-                filename, fdir, foundit = g.rapid_gfz_orbits(year,month,day)
+            #if pCtr == 'gfr':
+                # does not work and i cannot access the directory so I cannot fix it
+                #filename, fdir, foundit = g.rapid_gfz_orbits(year,month,day)
+                #filename, fdir, foundit = g.rapid_gfz_orbits(year,month,day)
+            #else:
+            if pCtr == 'esa':
+                    # this is ugly - but hopefully will work for now.  
+                filename, fdir, foundit = g.getsp3file_flex(year,month,day,pCtr)
+            elif (pCtr == 'gnss2'):
+                # use IGN instead of CDDIS
+                filename,fdir,foundit = g.avoid_cddis(year,month,day)
             else:
                 filename, fdir, foundit = g.getsp3file_mgex(year,month,day,pCtr)
         if foundit:
